=======
Credits
=======

Development Lead
----------------

* Robin Marquart <robin.marquart@ifremer.fr>
* Antoine Grouazel <antoine.grouazel@ifremer.fr>
* Alexis Mouche <alexis.mouche@ifremer.fr>
* Frederic Nouguier <frederic.nouguier@ifremer.fr>

Contributors
------------

None yet. Why not be the first?
